@@ -367,13 +367,11 @@ def start_dschecks(cnd, logact = 0):
 
    rcnt = 0
    check_dscheck_locks(cnd, logact)
-   if not CHKHOST['chkhost']: email_dschecks(cnd, logact)
+   email_dschecks(cnd, logact)
    purge_dschecks(cnd, logact)
 
-#   if 'NC' in PgOPT.params or not CHKHOST['chkhost']: return 0 
    if 'NC' in PgOPT.params: return 0 
    if CHKHOST['isbatch'] and 'CP' in PgOPT.params: check_dscheck_pends(cnd, logact)
-#   set_dscheck_options(CHKHOST['chkhost'], cnd, logact)
    reset_process_limits()
    if CHKHOST['isbatch']: rcnt = PgDBI.pgget("dscheck", "", "lockhost = '{}' AND pid > 0".format(PgLOG.PGLOG['PBSNAME']), logact)
 
@@ -471,7 +469,6 @@ def update_dscheck_time(pgrec, ltime, logact = 0):
       info = PgSIG.get_pbs_info(pgrec['pid'], 0, logact)
       if info:
          stat = info['State']
-         if stat == 'Q': stat = 'P'
          if stat != pgrec['status']: record['status'] = stat
    else:
       if pgrec['lockhost'] != PgLOG.PGLOG['HOSTNAME']: return    # connot update dscheck time
@@ -810,19 +807,10 @@ def get_pbs_options(pgrec, limit = 0, logact = 0):
 #
 def get_pbsqueue_option(pgrec):
 
-   cidx = pgrec['cindex']
-   for pname in PBSQUEUES:
-      if PBSQUEUES[pname]:
-         aname = pname
-      else:
-         qname = pname
-   pcnt = PgDBI.pgget("dscheck", '', "status = 'P' AND pbsqueue = '{}'".format(qname))
-   if pcnt > 1: qname = aname
-   if pgrec['pbsqueue'] != qname:
-      PgDBI.pgexec("UPDATE dscheck SET pbsqueue = '{}' WHERE cindex = {}".format(qname, cidx))
-      pgrec['pbsqueue'] = qname
+   qname = pgrec['pbsqueue']
+   if qname in PBSQUEUES: return PBSQUEUES[qname]
 
-   return PBSQUEUES[qname]
+   return None
 
 #
 #  build individual option string for given option name 
@@ -889,9 +877,7 @@ def fill_dscheck_info(ckrec, pid, host, logact = 0):
       record['pid'] = pid
       if host == PgLOG.PGLOG['PBSNAME']:
          info = PgSIG.get_pbs_info(pid, 0, logact, 2)
-         if info:
-            stat = info['State']
-            if stat == 'Q': stat = 'P'
+         if info: stat = info['State']
       else:
          record['runhost'] = PgLOG.PGLOG['HOSTNAME']
          record['bid'] = 0
@@ -939,8 +925,7 @@ def skip_dscheck_record(pgrec, host, logact = 0):
 def start_dsrqsts(cnd, logact = 0):
 
    check_dsrqst_locks(cnd, logact)
-#   if CHKHOST['chkhost']: return 1
-   if not CHKHOST['chkhost']: email_dsrqsts(cnd, logact)
+   email_dsrqsts(cnd, logact)
    purge_dsrqsts(cnd, logact)
    rcnd = cnd
    rcnd += ("status = 'Q' AND rqsttype <> 'C' AND (pid = 0 OR pid < ptcount) AND " +
@@ -1254,9 +1239,8 @@ def start_dsupdts(cnd, logact = 0):
 
    ctime = PgUtil.curtime(1)
    check_dsupdt_locks(cnd, logact)
-   if not CHKHOST['chkhost']:
-      email_dsupdt_controls(cnd, logact)
-      email_dsupdts(cnd, logact)
+   email_dsupdt_controls(cnd, logact)
+   email_dsupdts(cnd, logact)
 
    cnd += "pid = 0 and cntltime <= '{}' and action > '' AND einfo IS NULL ORDER by cntltime".format(ctime)
    pgrecs = PgDBI.pgmget("dcupdt", "*", cnd, logact)
